==> dynamic-table-from-input-node-module-test2-0.1.0.tgz: package/src/components/TableFormComponent.jsx <==
import React, { Component } from 'react';
import { withNamespaces } from 'react-i18next';
import { connect } from 'react-redux';
import DynamicTable from './TableForm';


class TableFormComponent extends Component {
    documentData;
    constructor(props) {
        super(props);
        this.parentTableData = [];
        this._isMounted = false;
        this.state = {
            title: "", 
            filterColumns:[], 
            rowHeader: [], 
            rowValues: [],
            parentLoaded : false
        }
    }


    componentDidMount() {
      if(this.props.filterColumns==="" || this.props.filterColumns===undefined || this.props.rowHeader===undefined || this.props.rowHeader==="" || this.props.rowValues===undefined || this.props.rowValues==="") {
        this.generateTemplate();
      } else {
        this.setState({ parentLoaded: true, title: this.props.title, filterColumns:this.props.filterColumns, rowHeader: this.props.rowHeader, rowValues: this.props.rowValues });
      }
        
    }

    generateTemplate() {
        let  response = {...this.props.responseData};
        let reskeys = Object.keys(response);
        this.parentTableData = [];
        let self = this;
        reskeys.forEach(function(value) {
            if(Object.prototype.toString.call(response[value]) === '[object Array]') {
                let respvalkeys = Object.keys(response[value][0]);
                let rowheader = [];
                let rowfilter = [];
                let rowvalues = response[value];
                respvalkeys.forEach(function(value1, index){
                    let obj = {
                        "id": value1+index,
                        "name": value1,
                        "numeric": false, 
                        "disablePadding": true, 
                        "label" : value1
                    };
                    rowheader.push(obj);
                    rowfilter.push(value1)
                })
                let tableData = {
                    "title" : value,
                    "rowheader" : rowheader,
                    "rowvalues" : rowvalues,
                    "rowfilter" : rowfilter
                }
                self.parentTableData.push(tableData);
            }
        })
        this.setState({ parentLoaded: true, title: this.parentTableData[0].title, filterColumns:this.parentTableData[0].rowfilter, rowHeader: this.parentTableData[0].rowheader, rowValues: this.parentTableData[0].rowvalues });
    }

    componentWillUnmount() {
        this._isMounted = false;
    }


    render() {
        return (
            <div>
                { (() => {
                    if(this.state.parentLoaded) {
                            return(
                                <div>
                                    <DynamicTable
                                    tableName={this.state.title}
                                    lang={"en"}
                                    langCheckValue={"ar"}
                                    viewClick={this.props.viewClick} 
                                    buttonHeaderName={this.props.buttonHeaderName}
                                    viewEnable={this.props.viewEnable} 
                                    viewBtnName={this.props.viewBtnName}
                                    deleteEnable={this.props.deleteEnable}
                                    deleteBtnName={this.props.deleteBtnName}
                                    filterColumns={this.state.filterColumns} 
                                    history={this.props.history} 
                                    rowHeader={this.state.rowHeader} 
                                    rowValues={this.state.rowValues} 
                                    enablePagination={this.state.rowValues.length >= 5 ? "block" : "none"}
                                    handleOnViewBtnClick={this.props.handleViewClick} 
                                    handleOnDeleteBtnClick={this.props.handleDeleteClick} />
                                </div>
                            )
                    }
                })()}
            </div >
        );
    }
}

const mapStateToProps = state => ({
});

const mapDispatchToProps = {
};

export default withNamespaces()(connect(mapStateToProps, mapDispatchToProps)(TableFormComponent));

==> dynamic-table-from-input-node-module-test2-1.0.1.tgz: package/src/components/TableFormComponent.jsx <==
import React, { Component } from 'react';
import { withNamespaces } from 'react-i18next';
import { connect } from 'react-redux';
import DynamicTable from './TableForm';


class TableFormComponent extends Component {
    constructor(props) {
        super(props);
        this.parentTableData = [];
        this._isMounted = false;
        this.state = {
            title: "", 
            filterColumns:[], 
            rowHeader: [], 
            rowValues: [],
            parentLoaded : false
        }
    }


    componentDidMount() {
      if(this.props.filterColumns==="" || this.props.filterColumns===undefined || this.props.rowHeader===undefined || this.props.rowHeader==="" || this.props.rowValues===undefined || this.props.rowValues==="") {
        this.generateTemplate();
      } else {
          console.log("this.props.tableName>>>",this.props.tableName)
        this.setState({ filterColumns:this.props.filterColumns, rowHeader: this.props.rowHeader, rowValues: this.props.rowValues, parentLoaded: true });
      }
        
    }

    generateTemplate() {
        let  response = {...this.props.responseData};
        let reskeys = Object.keys(response);
        this.parentTableData = [];
        let self = this;
        reskeys.forEach(function(value) {
            if(Object.prototype.toString.call(response[value]) === '[object Array]') {
                let respvalkeys = Object.keys(response[value][0]);
                let rowheader = [];
                let rowfilter = [];
                let rowvalues = response[value];
                respvalkeys.forEach(function(value1, index){
                    let obj = {
                        "id": value1+index,
                        "name": value1,
                        "numeric": false, 
                        "disablePadding": true, 
                        "label" : value1
                    };
                    rowheader.push(obj);
                    rowfilter.push(value1)
                })
                let tableData = {
                    "title" : value,
                    "rowheader" : rowheader,
                    "rowvalues" : rowvalues,
                    "rowfilter" : rowfilter
                }
                self.parentTableData.push(tableData);
            }
        })
        this.setState({ parentLoaded: true, title: this.parentTableData[0].title, filterColumns:this.parentTableData[0].rowfilter, rowHeader: this.parentTableData[0].rowheader, rowValues: this.parentTableData[0].rowvalues });
    }

    componentWillUnmount() {
        this._isMounted = false;
    }


    render() {
        return (
            <div>
                { (() => {
                    if(this.state.parentLoaded) {
                            return(
                                <div>
                                    <DynamicTable
                                    tableName={this.state.title ? this.state.title : this.props.tableName}
                                    lang={"en"}
                                    langCheckValue={"ar"}
                                    buttonHeaderName={this.props.buttonsHeaderColumnName}
                                    viewEnable={this.props.buttonOneEnable} 
                                    viewBtnName={this.props.buttonOneName}
                                    deleteEnable={this.props.buttonTwoEnable}
                                    deleteBtnName={this.props.buttonTwoName}
                                    filterColumns={this.state.filterColumns} 
                                    history={this.props.history} 
                                    rowHeader={this.state.rowHeader} 
                                    rowValues={this.state.rowValues} 
                                    enablePagination={this.state.rowValues.length >= 5 ? "block" : "none"}
                                    handleOnViewBtnClick={this.props.handleOnbuttonOneClick} 
                                    handleOnDeleteBtnClick={this.props.handleOnbuttonTwoClick} />
                                </div>
                            )
                    }
                })()}
            </div >
        );
    }
}

const mapStateToProps = state => ({
});

const mapDispatchToProps = {
};

export default withNamespaces()(connect(mapStateToProps, mapDispatchToProps)(TableFormComponent));
